All Classes and Interfaces

Class
Description
 
 
 
Access Control.
Action Performed
ActionListener
 
Address {PCI, USB}
Angles3 - Stores Euler angles (x,y,z).
 
ANSI client-side functions.
ANSI server side functions.
Convert ASCII-8bit to Unicode.
Audio
FIFO buffer for audio samples (16bit only).
Abstract Class that defines an Audio File Writer.
AudioGenerate.
AudioInput.
Audio Output.
Base16 (hex) encoder / decoder Hex Chars : 0-9,a-f (lower case)
Base64 encoder / decoder.
BasicTheme
BCD Encoding 4 bits per digit (0-9).
Big Endian get/set functions.
Speex bit packing and unpacking class.
Block (div) container.
Internal class to provide BMP file support.
 
 
 
Build Tools
Button
Button
Button
Keeps track of Call Details based on the 'callid' field of SIP messages.
Every call has 2 sides, originator and terminator.
Keeps track of Call Details based on the 'callid' field of SIP messages.
Web Camera API
Camera native API.
 
Camera JNI
Canvas - allows drawing custom OpenGL objects.
Canvas for 2D and 3D output.
Abstract class that is the base for the various Codebook search methods.
Centered Panel to display components.
Change handler.
Change Listener
Change Password Panel
CheckBox
Check Box
CheckBox
CIP : Connection Manager : Request
OpenCL methods.
OpenCL native API.
 
Click handler.
Wayland client.
OpenCL JNI implementation
Codebook tables
Codec.
Codec Info
Codec Type.
Color - ARGB
WebUI Color
Color Chooser Popup.
Column - lays out components in a column.
Column - display components in a column.
Combo Box - combines TextField / Button and a ListBox (in a ScrollBox)
ComboBox
Component - base class for all UI elements.
Base class for all components.
 
Com Port API.
Com Port native API.
 
Com Port JNI
Wayland Compositor
Compression and Serialization.
 
Compute kernels (computations).
Condition interface.
Common Config Servlet.
Confirm Action Panel.
Console (alternative to System.in/out).
 
 
User contact.
Container - contains other Components.
Base class for components that can "contain" other components.
Controller for PLCs.
Controller (optional).
Data types for write() function.
Controller Types
Converts 3d model files to JF3D.
Convert '-' properties to '_' properties for bash scripts.
CopyPath
COTP - Connection-Oriented Transport Protocol (ISO 8073/X.224)
CPU Hogger.
Dark Theme
DatagramInputStream allows DatagramSocket to be used as an InputStream.
DatagramOutputStream allows DatagramSocket to be used as an OutputStream.
DBus IPC/RPC implementation.
Options provides increase control of DBus operations.
DBus Transport base class.
DebugState.
 
Speex Decoder inteface, used as a base for the Narrowband and sideband decoders.
deltree : Delete files/folder that are x days old.
DesktopCache maintains cache of desktop files.
 
Host Device (USB or PCI).
DHCP Server.
 
DHCP Notification interface.
Dialog interface
Dimension
Dimension
Direction
Disk.
Message Dispatch interface.
Dispatcher.
DNS Client.
DNS Server.
 
Docker implementation of ContainerManager
 
 
DTMF (Dual Tone Multi Freq).
Edit Group Panel
Edit User Panel
EMail.
 
Speex Encoder interface, used as a base for the Narrowband and sideband encoders.
IPC Endpoint
EtherNet/IP (Industrial Protocol)
Executes Graal 'native-image' command.
ExecGraalAgent
ExecProject
Executable Symbol Lookup.
FFM support class.
FFMArray.
Field
FileDialog
File Dialog (used by jfFile)
 
File splitter.
FileSync client.
File Sync Server.
A FilteredAudioInputStream is an AudioInputStream with buffers to facilitate transcoding the audio.
Filters
 
Interface to allow handling of FindDialog events.
Find and Replace utility.
FlexBox - size auto fills parent width/height.
FlexBox.
Folder Change Event Listener.
Font
Component with a font.
FontMetrics
Format Source code to assist in Java to C# conversion.
Reference Fragment Shader.
Frustum (viewable area of a perspective)
FTP client class.
 
FTP Server Config App.
FTPS (Secure FTP).
FTP Server.
 
Encodes/decodes g711 packets (A-Law).
Encodes/decodes g711 packets (U-Law).
G.722 codec.
Encodes/decodes g729a packets.
 
GenDEB : Generates Debian .deb files.
GenDMG : Generates MacOS .dmg files.
Generates executable for platform.
Generates FFM code from API class.
Generate icons
GenKeyPair dialog.
GenMSI : Generates Windows MSI file (wixtoolset)
GenPAC : Generates Arch Linux .pac files.
genpkginfo : Generates Linux package info files.
GenRPM : Generates RedHat .rpm files.
 
GetTextPopup.
Processes a git repo as a package repo.
OpenGL API.
 
OpenGL JNI implementation.
GPIO.
GPIO native API.
 
GPIO JNI implementation
grep CLI
Grid Layout
User Group
List of Groups.
Groups Panel
Encodes/decodes GSM packets.
 
 
 
 
Hardware setup for a Virtual Machine.
LSP Quantisation and Unquantisation (high)
HMACT64 MessageDigest.
Host Details
HTML generation functions.
HTML container for generic types
HTTP Client.
Internal HTTP Buffer.
HTTP Parameters.
Part a of multipart POST
Progress Listener
HTTPS Client.
I2C.
I2C native API
 
I2C JNI
Icon.
IconCache of icons used in desktop files.
Icon Resources
IFrame to display another webpage.
IFrame in a Panel
Image.
Image.
ImageConvert utility.
Speex in-band and User in-band controls.
Panel inited.
Inline Block
Inner Panel to display components with a border.
InputDialog
Install Project files.
 
IP4.
IP4 + Port
IP6.
IP6 + Port
IPC interface
Intermec Printing Language (IPL).
IQN
 
JBusClient is the client side of inter-process communications (RPC).
JBusServer is a server for inter-process communications (IPC).
A collection of useful static methods.
JF Array generic.
JFArrayByte.
JFArrayChar.
JFArrayDouble.
JFArrayFloat.
JFArrayInt.
JFArrayShort.
AWT/Swing misc functions
Byte Buffer (fifo).
Class Loader from a ClassPath.
Clipboard functions.
 
 
 
 
 
 
 
JF Heap.
Graphics image with many functions.
 
Provides a uniform layout style.
File Locking object.
JFLog is a file logger with support for multiple files and optional outputs to System.out as well.
JFLog compatible with SLF
JFNative provides native library loading functions.
JFontChooser.
 
JFPrint client.
JFPrintApp.
JFPrintServer.
 
JFProfiler
jfControls Tag
Thread (task) for ProgressDialog.
JFTaskListener interface.
Extends JTextArea to provide some extra features such as overwrite mode, and undo/redo.
Convenience thread to pass in value via ctor.
A simpler to use Timer, that uses a callback interface.
JSON (JavaScript Object Notation) parser.
 
JTrayIcon (swing version of java.awt.TrayIcon).
Virtual KeyCodes
KeyDown Event
KeyEvent
KeyEvents.
KeyEvents
Key Management keystore.
JF Key Manager dialog.
KeyPad for TextComponent
Key Generation Parameters
KeyUp
Label
Label
Layers Panel.
Layout Manager
LayoutMetrics.
LSP Quantisation and Unquantisation (Lbr)
LDAP client functions.
Little Endian get/set functions.
Native Library
Line of text in a Buffer.
Line Styles
Common functions for Linux administration.
 
 
 
 
 
 
 
 
List
Desc : Lists chunks in a 3DS file.
listblend : Lists chunks in a .blend file.
List Box
ListBox
ListItem
LLRP API to read/write RFID tags from compatible controllers.
LLRP Events interface
Linux Native API
Linux PTY support.
Component Loaded
Location.
LoggerFactory
Login Panel
Callback interface to validate provided password.
 
 
LPC - and Reflection Coefficients.
Line Spectral Pair
Abstract class that is the base for the various LSP Quantisation and Unquantisation methods.
Abstract class that is the base for the various LTP (Long Term Prediction) Quantisation and Unquantisation methods.
Long Term Prediction Quantisation and Unquantisation (3Tap)
Long Term Prediction Quantisation and Unquantisation (Forced Pitch)
Linux Container interface
Linux Container Manager interface
Linux Image.
Container run-time option.
MAC Address
Mac Native API
4x4 matrix
MD4 MessageDigest (128bit).
MD5 MessageDigest (128-bit).
JavaForce Media File.
Media API
Media audio decoder.
Media audio encoder.
Base class for Media Coders.
Media : Base class for Audio and Video elements.
 
Base class for MediaInput, MediaOutput and MediaEncoder, MediaDecoder.
MediaInput.
Interface for reading/writing files for media coders.
Media native API (JNI implementation)
MediaOutput.
Media video decoder.
Media video encoder.
Menu
Menu (place on MenuBar or PopupMenu)
MenuBar
MenuItem
MessageDialog
Message Panel.
Miscellaneous functions
 
Modbus Server for Raspberry PI.
 
 
 
 
 
 
 
 
 
 
 
 
 
Model is a set of Object3's that all share the same base orientation (rotation, translation, scale).
Model_IO is base interface for Model import/export functions.
Autodesk 3DS reader.
Blender blend reader.
AutoDesk FBX reader.
JF3D - 3d model format designed for JavaForce.
JSON Model reader.
Wavefront obj reader.
Adobe STL reader.
 
 
Monitor Directory utility
Monitor Folder for changes.
Monitor Folder API.
 
MonitorFolder JNI implementation.
Mouse Buttons
MouseDown handler.
MouseEnter handler.
Mouse Event details
MouseEvents
MouseMove handler.
MouseUp handler.
Moved handler.
MQTT client.
MQTT Server Config App.
MQTT Events
MQTT Forward.
MQTTServer (broker) service
 
MQTT client viewer.
Music player.
Each audio sample for an Instrument must be 16bit, 44100Hz, mono
 
 
 
 
 
 
 
 
Either plays wav file or generates intermittent beep to party member on hold.
Name interface
Narrowband Codec.
Narrowband Speex Decoder
Narrowband Speex Encoder
LSP Quantisation and Unquantisation (narrowband)
Network guest NIC.
Network Bridge - "virtual switch".
Network Interface Settings
NetworkConfig
Linux Network Control
Network physical interface.
NetworkConfig
Network virtual interface.
Network VLAN used by guest VM's.
New Group Panel
New User Panel
Noise codebook search
Object3 consists of vertex points, and polygons (usually triangles).
GL Offscreen rendering buffer.
Calculates the CRC checksum for Ogg packets.
Ogg Speex Writer
OpenFile CLI utility.
opus rtp coder.
 
 
Package everything for current OS (WIP).
SIP/RTSP Packet
PacketBuffer.
Packet Capture API (pcap)
Packet Pool
PacketReceiver
Pad - to add padding
Panel to display components.
Parsing command line options.
pcap API.
 
pcap JNI implementation.
Converts a PCM 16bits/sample mono audio stream to Ogg Speex
Writes basic PCM wave files from binary audio data.
Convert PDF to Images.
Plane vectors.
pngalpha
Internal class for pgm, ppm images.
Point - 2D Position
Point
POP3 client.
 
POP3 Server Config App.
POP3 Server.
 
Popup Menu
Popup Panel (or Window)
Site Profile
ProgressBar.
Progress bar.
ProgressDialog.
properties.
Proxy Server Config App.
Web Proxy Server
 
Publish to maven central (sonatype.org).
Retrieves PulseAudio configuration.
 
 
 
 
 
Quaternion.
Raw Audio File Writer.
Rectangle
Relay Stream.
Renders a view of a Scene.
ReplaceDialog.
The interface used by ReplaceDialog for event handling.
Reset Password Panel
Resized handler.
Image Resize Operation
Resource
Resource Manager.
RFB Protocol (VNC) server/client.
 
 
 
 
Rotate3 stores angle-axis rotation.
Routing entry
Row.
Row - lays out components in a row.
Row - display components in a row.
 
 
RTP (Real-Time Transport Protocol).
RTPAudioCoder.
RTPChannel
Encodes/Decodes RTP/H263 packets.
Encodes/Decodes RTP/H263+ packets (H263-1998).
Encodes/Decodes RTP/H263+ packets (H263-2000).
Encodes/Decodes RTP/H264 packets.
Encodes/Decodes RTP/H265 (HEVC) packets.
Interface to allow RTP to trigger callbacks.
Encodes/Decodes RTP/JPEG packets (type 26).
RTPVideoCoder.
Encodes/Decodes RTP/VP8 packets.
Encodes/Decodes RTP/VP9 packets.
Base class for RTSP communications (Real Time Streaming Protocol).
Handles the client end of a RTSP link.
 
RTSP Client Interface
Handles RTSP packets directly.
Handles the server end of a RTSP link.
 
RTSP Server Interface
RTSP session
Registers the RTSP protocol with java.net.URL.
 
 
 
 
 
Sideband Codec.
Sideband Speex Decoder
Wideband Speex Encoder
Scale 3 stores scale.
Scene is a primitive 3D framework.
Screen interface
Scripting support for JFTerm.
Scripting Utils
Scroll Bar
Scroll Box - provides a view port view into another larger component with scroll bars.
Scroll Link.
Scroll Panel
SDP (Session Description Protocol)
 
 
 
 
Secret.
Select From List Popup Panel
JF Service control CLI Created : July 9, 2012
Service Control (systemctl)
ServiceProvider
FTP over SSH.
SharedMemory
Runs shell processes with input/output and sudo password authentication.
 
ShellProcessListener.
ShellProcessListenerAdapter.
 
Base class for SIP communications (Session Initiation Protocol).
Handles the client end of a SIP link.
 
Callback interface for handling SIP messages for a SIP client.
Handles SIP packets directly.
Handles the server end of a SIP link.
Callback interface for handling SIP messages for a SIP server.
Represents memory or storage sizes.
Slider
smbget CLI.
SMTP client.
Email Attachment
SMTP Server Config App
SMTPRelay Server Config App
SMTP Relay Server.
 
SMTP Server.
 
 
VM Snapshot
SOCKS client.
SOCKS Server Config App
Socks 4/4a/5 Server.
 
Encodes/decodes speex packets.
Converts an Ogg Speex bitstream into a PCM 16bits/sample audio stream.
Speex native API
Provider for Speex audio file reading services.
Provider for Speex audio file writing services.
Main Speex Decoder class.
Main Speex Encoder class.
Encodings used by the Speex audio decoder.
 
FileFormatTypes used by the Speex audio decoder.
A format conversion provider provides format conversion services from one or more input formats to one or more output formats.
speex JNI
SplitPanel - divides two Panels vertically or horizontally.
Split shape codebook search
JDBC SQL functions.
SQLPool based on Tomcat Connection Pool.
Secure RTP.
Secure RTP using Java9 DTLS (not working yet).
SRTPContext.
SSH Client.
SSH Connection options.
SSH Server Config App
SSH Server
 
Task status callback.
Stereo
Storage pool registered with libvirt.
STUN (w/ TURN support) client.
 
 
 
STUN Server Config App
STUN (w/ TURN support) server.
 
Speex SubMode
Subnet : IP4 + Mask
sudo Created : Apr 13, 2012
 
Internal class to provide SVG file support.
SVG Text Editor
System Bus Names for jfLinux
Tools for systemd
SystemInfo
Tables store Row's in memory for fast access.
Table
List of tables stored in a folder.
Table that logs Row's with date/time.
Tabbed Panel
Monitors a PLC Tag.
Tag Listener interface.
Tag Types (0x00 - 0xff)
Task.
Task Event
Task Log.
Task Log UI Panel
Tasks.
TaskUI
TCP Server/Client Transport for DBus.
Telnet client.
TelnetDecoder.
Linux Terminal.
TestAWT
Tests Camera function
Test OpenCL
TestEvents
TestGC.
OpenGL Test
Test WebUI / WebGL.
 
Test WebUI / WebGL.
 
Test IPC (DBus)
 
Test LDAP.
Test 3d math functions.
TestMedia.
Test WebUI / Media.
Opus test
Tests PCAP
Raspberry Pi Test
 
Test PLC (Controller)
TestProxy
Test SOCKS server
Test SSL.
 
 
 
 
 
Udp
 
 
 
Test : Print System Properties
TestUI
Test WebUI.
ANSI Tetris game.
TextArea
TextArea
TextArea Popup.
Text Box
Component with text content.
Text Component
TextField
Text Field
TextField
TextField Popup.
Texture stores a 2D Texture (image).
Base class for Themes.
Processes Runnable objects with a Thread pool.
The interface used by JFTimer for event handling.
TitleBar to be placed in PopupPanel
Toggle Button
 
ToolBar
TPKT Header
Translate3 stores a translation (movement).
SIP Transport interface.
TransportInterface
SIP TCP Transport.
SIP TCP Transport Server.
SIP TLS Transport.
SIP TLS Transport.
Transport Type
SIP UDP Transport
Tree
Tree Event
WebUI TreeModel
WebUI TreeModelEvent
WebUI TreeModelListener
TreeNode
WebUI TreePath
Unsigned Byte
UI native API
UI Events.
 
UI JNI
Unsigned Integer
UIRender - main render loop.
Unsigned Long
Uninstall Project files.
A Unix encryption which is uni-directional.
DBus over Unix Socket Transport.
updatedesktopdatabase.
 
 
Upload Button
User account.
List of Users.
Users Panel
Unsigned Short
UTF8 decoder.
UV Map - 2D Texture coordinates (see Object3)
Validate a component.
This class analyses the signal to help determine what bitrate to use when the Varible BitRate option has been selected.
Vector3 stores one vector (x,y,z).
Vector3 stores one vector (x,y,z) with optional w component (default = 1.0f).
Prints JavaForce version info.
Vertex3 store one vertex point (x,y,z) with texture coordinates (u,v).
Reference Vertex Shader.
Video
FIFO buffer for video frames (images).
View JF Log File(s) Views all registered JFLog files.
View Log File
Virtual Machine registered with libvirt.
Visible Event
VM native API
 
Provides some statistics of the VM Host.
VM JNI
VMProvider.
VNC Client.
VNCJavaRobot
VNCRobot interface.
VNCServer (5900).
 
VNCSessionClient.
VNCSessionServer.
 
VNCWebConsole.
VNC Web Server (5800/5843).
Vector Quantization.
VSS - Volume Shadow Service command line API
Service to send out WakeOnLan packets.
Wav audio file.
Loads a WAV file specific to VoIP requirements (must be 8000Hz, mono, 16bit PCM).
Wayland native JNI Each of the wl_start...() methods must be invoked on a new thread.
Web server that serves files from current folder.
WebUI API Client (WIP)
WebUI API Server (WIP)
Web File uploaded to server.
Web Server handler interface.
WebRequest Created : Aug 23, 2013
 
WebResponse Created : Aug 23, 2013
Web server.
Web server that redirects users to a different port.
WebSocket
WebSocketHandler
WebClient.
WebUI Handler
WebUI Server.
WebUI Servlet context
WebUIServletContext.
A class to handle file uploads (default max 64MBs)
OpenGL Window.
WindowEvents
Windows Native API
Tool to add resources to Windows PE exe files.
Windows Pipes (JNI or FFM)
Windows Pipes native API
 
WinPipe JNI
DBus over Windows Pipes Transport.
WinService : Windows Service API
Heat for JavaForce (wixtoolset).
wl_callback object.
wl_compositor object.
wl_display object.
wl_object : Wayland Base Object
wl_registry object.
wl_shm object.
wl_shm_pool object.
X11 native JNI methods
X11Listener.
Utility to work with xar files (WIP).
xml CLI.
XML file.
XML is a TreeModel data model that encapsules a complete XML file.
XML is a TreeModel data model that encapsules a complete XML file.
XMLEvent is an interface for a callback handler used during XML loading.
XMLEvent is an interface for a callback handler used during XML loading.
Internal class for XPM images.