Package javaforce.awt
package javaforce.awt
This package contains classes dependent on Java AWT.
-
ClassDescriptionInterface to allow handling of FindDialog events.AWT/Swing misc functionsClipboard functions.Graphics image with many functions.Provides a uniform layout style.JFontChooser.Extends JTextArea to provide some extra features such as overwrite mode, and undo/redo.JTrayIcon (swing version of java.awt.TrayIcon).MQTT client viewer.Convert PDF to Images.ProgressDialog.ReplaceDialog.The interface used by ReplaceDialog for event handling.RFB Protocol (VNC) server/client.SVG Text EditorView JF Log File(s) Views all registered JFLog files.View Log FileVNC Client.VNCJavaRobotVNCRobot interface.VNCServer (5900).VNCSessionClient.VNCSessionServer.VNCWebConsole.VNC Web Server (5800/5843).XML is a TreeModel data model that encapsules a complete XML file.XMLEvent is an interface for a callback handler used during XML loading.