Class JBusClient
java.lang.Object
javaforce.bus.JBus
javaforce.bus.JBusClient
- All Implemented Interfaces:
EndPoint
JBusClient is the client side of inter-process communications (RPC).
Based on DBus. JBusClient is an unnamed end point.
Created : Apr 9, 2012
- Author:
- pquiring
-
Field Summary
-
Constructor Summary
Constructors -
Method Summary
Methods inherited from class JBus
connect, disconnect, dispatch, getBusName, getEndPointName, invoke, setDispatch, setTimeout, signal, subscribe, unsubscribeModifier and TypeMethodDescriptionbooleanconnect()Connect to message bus.voidCloses connection to message bus.Dispatches inbound method call.Returns bus name requested or assigned.Returns bus nameInvoke a method on another member on the message bus.voidsetDispatch(Dispatch dispatch) Setup alternative message dispatch.voidsetTimeout(int ms) Set DBus timeout.Invoke a method on all clients that have subscribed to method.booleanSubscribe to a signal from another client.booleanunsubscribe(String sender, String method) Unsubscribe to a signal from another client.
-
Constructor Details
-
JBusClient
Creates new client.- Parameters:
obj- = object with methods to invoke for RPC calls
-