Class LbrLspQuant
java.lang.Object
javaforce.codec.speex.LspQuant
javaforce.codec.speex.LbrLspQuant
- All Implemented Interfaces:
Codebook
LSP Quantisation and Unquantisation (Lbr)
- Version:
- $Revision$
- Author:
- Jim Lawrence, helloNetwork.com, Marc Gimpel, Wimba S.A. ([email protected])
-
Field Summary
Fields inherited from class LspQuant
MAX_LSP_SIZEFields inherited from interface Codebook
cdbk_nb, cdbk_nb_high1, cdbk_nb_high2, cdbk_nb_low1, cdbk_nb_low2, exc_10_16_table, exc_10_32_table, exc_20_32_table, exc_5_256_table, exc_5_64_table, exc_8_128_table, gain_cdbk_lbr, gain_cdbk_nb, h0, h1, hexc_10_32_table, hexc_table, high_lsp_cdbk, high_lsp_cdbk2, NB_CDBK_SIZE, NB_CDBK_SIZE_HIGH1, NB_CDBK_SIZE_HIGH2, NB_CDBK_SIZE_LOW1, NB_CDBK_SIZE_LOW2Modifier and TypeFieldDescriptionstatic final int[]Codebook (narrowband)static final int[]Codebook (narrowband)static final int[]Codebook (narrowband)static final int[]Codebook (narrowband)static final int[]Codebook (narrowband)static final int[]Excitation Codebookstatic final int[]Excitation Codebookstatic final int[]Excitation Codebookstatic final int[]Excitation Codebookstatic final int[]Excitation Codebookstatic final int[]Excitation Codebookstatic final int[]Gain Codebook (LBR)static final int[]Gain Codebook (narrowband)static final float[]QMF (Quadratic Mirror Filter) tablestatic final float[]QMF (Quadratic Mirror Filter) tablestatic final int[]Excitation Codebookstatic final int[]Excitation Codebookstatic final int[]LSP Codebook (high)static final int[]LSP Codebook (high)static final intstatic final intstatic final intstatic final intstatic final int -
Constructor Summary
Constructors -
Method Summary
Methods inherited from class LspQuant
lsp_quant, lsp_weight_quant, unpackPlusModifier and TypeMethodDescriptionprotected static intlsp_quant(float[] x, int xs, int[] cdbk, int nbVec, int nbDim) LSP quantification Note: x is modifiedprotected static intlsp_weight_quant(float[] x, int xs, float[] weight, int ws, int[] cdbk, int nbVec, int nbDim) LSP weighted quantification Note: x is modifiedprotected voidunpackPlus(float[] lsp, int[] tab, Bits bits, float k, int ti, int li) Read the next 6 bits from the buffer, and using the value read and the given codebook, rebuild LSP table.
-
Constructor Details
-
LbrLspQuant
public LbrLspQuant()
-
-
Method Details
-
quant
-
unquant
-