Class NbDecoder
java.lang.Object
javaforce.codec.speex.NbCodec
javaforce.codec.speex.NbDecoder
Narrowband Speex Decoder
- Version:
- $Revision$
- Author:
- Jim Lawrence, helloNetwork.com, Marc Gimpel, Wimba S.A. ([email protected])
-
Field Summary
FieldsModifier and TypeFieldDescriptionprotected booleanprotected final Inbandprotected final Randomprotected final StereoFields inherited from class NbCodec
awk1, awk2, awk3, bufSize, dtx_enabled, exc_gain_quant_scal1, exc_gain_quant_scal3, excBuf, excIdx, filters, first, frameSize, frmBuf, frmIdx, gamma1, gamma2, innov, interp_qlpc, interp_qlsp, lag_factor, lpc, lpc_floor, lpcSize, m_lsp, max_pitch, mem_sp, min_pitch, NB_FRAME_SIZE, NB_SUBMODE_BITS, NB_SUBMODES, nbSubframes, old_qlsp, pi_gain, pre_mem, preemph, qlsp, subframeSize, submodeID, submodes, VERY_SMALL, voc_m1, voc_m2, voc_mean, voc_offset, windowSizeFields inherited from interface Codebook
cdbk_nb, cdbk_nb_high1, cdbk_nb_high2, cdbk_nb_low1, cdbk_nb_low2, exc_10_16_table, exc_10_32_table, exc_20_32_table, exc_5_256_table, exc_5_64_table, exc_8_128_table, gain_cdbk_lbr, gain_cdbk_nb, h0, h1, hexc_10_32_table, hexc_table, high_lsp_cdbk, high_lsp_cdbk2, NB_CDBK_SIZE, NB_CDBK_SIZE_HIGH1, NB_CDBK_SIZE_HIGH2, NB_CDBK_SIZE_LOW1, NB_CDBK_SIZE_LOW2 -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionintDecode the given input bits.intdecodeLost(float[] out) Decode when packets are lost.voiddecodeStereo(float[] data, int frameSize) Decode the given bits to stereo.booleanReturns whether perceptual enhancement is enabled or disabled.voidinit(int frameSize, int subframeSize, int lpcSize, int bufSize) InitialisevoidsetPerceptualEnhancement(boolean enhanced) Enables or disables perceptual enhancement.
-
Field Details
-
random
-
stereo
-
inband
-
enhanced
protected boolean enhanced
-
-
Constructor Details
-
NbDecoder
public NbDecoder()Constructor
-
-
Method Details
-
init
-
decode
Decode the given input bits.- Specified by:
decodein interfaceDecoder- Parameters:
bits- - Speex bits buffer.out- - the decoded mono audio frame.- Returns:
- 1 if a terminator was found, 0 if not.
- Throws:
StreamCorruptedException- If there is an error detected in the data stream.
-
decodeLost
public int decodeLost(float[] out) Decode when packets are lost.- Parameters:
out- - the generated mono audio frame.- Returns:
- 0 if successful.
-
decodeStereo
public void decodeStereo(float[] data, int frameSize) Decode the given bits to stereo.- Specified by:
decodeStereoin interfaceDecoder- Parameters:
data- - float array of size 2*frameSize, that contains the mono audio samples in the first half. When the function has completed, the array will contain the interlaced stereo audio samples.frameSize- - the size of a frame of mono audio samples.
-
setPerceptualEnhancement
public void setPerceptualEnhancement(boolean enhanced) Enables or disables perceptual enhancement.- Specified by:
setPerceptualEnhancementin interfaceDecoder- Parameters:
enhanced-
-
getPerceptualEnhancement
public boolean getPerceptualEnhancement()Returns whether perceptual enhancement is enabled or disabled.- Specified by:
getPerceptualEnhancementin interfaceDecoder- Returns:
- whether perceptual enhancement is enabled or disabled.
-