Class Row
java.lang.Object
javaforce.db.Row
- All Implemented Interfaces:
Serializable
Row.
This class holds data for one row in a database table.
Extend this class to hold user data.
- See Also:
-
Nested Class Summary
Nested Classes -
Field Summary
FieldsModifier and TypeFieldDescriptionintauto-increment id assigned by containing Tablestatic final longlonginsert timestamp -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
serialVersionUID
public static final long serialVersionUID- See Also:
-
id
public int idauto-increment id assigned by containing Table -
timestamp
public long timestampinsert timestamp
-
-
Constructor Details
-
Row
public Row()
-
-
Method Details
-
compare
Override this method to sort your rows.- Returns:
- 0=equal -1=this is lower +1=other is lower
-