Class DBus.Options
java.lang.Object
javaforce.ipc.DBus.Options
- Enclosing class:
DBus
Options provides increase control of DBus operations.
-
Field Summary
FieldsModifier and TypeFieldDescriptionintidle time before an idle thread is closed (if # threads is more than minThreads).intmax threads for processing inbound calls queue.intmin threads for processing inbound calls queue.Transport to use (null = create default for OS) -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
transport
Transport to use (null = create default for OS) -
minThreads
public int minThreadsmin threads for processing inbound calls queue. Default = 1 -
maxThreads
public int maxThreadsmax threads for processing inbound calls queue. Default = 16 -
idleSeconds
public int idleSecondsidle time before an idle thread is closed (if # threads is more than minThreads). Default = 60
-
-
Constructor Details
-
Options
public Options()
-