Interface EndPoint

All Known Implementing Classes:
JBus, JBusClient, JBusServer, TestIPC.TestEndPoint

public interface EndPoint
IPC Endpoint
Author:
pquiring
  • Method Summary

    Modifier and Type
    Method
    Description
    dispatch(String method, Object[] args)
    Dispatch function called to this endpoint.
    Returns end point name in reverse DNS notation.
  • Method Details

    • getEndPointName

      String getEndPointName()
      Returns end point name in reverse DNS notation. Return null for client end points to have a generic name provided. On Linux the Javaforce package will install a DBus conf that will allow root to use names that start with "javaforce." or you could install your own into /etc/dbus-1/system.d See DBus.getBusName() to get supplied name. Example : com.example.MyService
      Returns:
      End Point name (null to request system supplied name)
    • dispatch

      Object dispatch(String method, Object[] args) throws Exception
      Dispatch function called to this endpoint.
      Parameters:
      method - = method invoked
      args - = arguments
      Returns:
      method return value or null if error
      Throws:
      Exception