Interface IPC

All Known Implementing Classes:
DBus

public interface IPC
IPC interface
Author:
pquiring
  • Method Summary

    Modifier and Type
    Method
    Description
    boolean
    Connect to IPC service.
    boolean
    Disconnect from IPC service.
    Return name on message bus.
    invoke(String dest, String method, Object... args)
    Invoke RPC on specified end point.
    boolean
    signal(String method, Object... args)
    Invoke RPC to all end points that have subscribed to the method.
    boolean
    subscribe(String sender, String method)
    Subscribe to a signal from another client.
    boolean
    unsubscribe(String sender, String method)
    Unsubscribe to a signal from another client.
  • Method Details

    • connect

      boolean connect()
      Connect to IPC service.
    • disconnect

      boolean disconnect()
      Disconnect from IPC service.
    • getBusName

      String getBusName()
      Return name on message bus.
    • invoke

      Object invoke(String dest, String method, Object... args) throws Exception
      Invoke RPC on specified end point.
      Throws:
      Exception
    • subscribe

      boolean subscribe(String sender, String method)
      Subscribe to a signal from another client.
    • unsubscribe

      boolean unsubscribe(String sender, String method)
      Unsubscribe to a signal from another client.
    • signal

      boolean signal(String method, Object... args)
      Invoke RPC to all end points that have subscribed to the method.