Class VMJNI
java.lang.Object
javaforce.jni.VMJNI
- All Implemented Interfaces:
VMAPI
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic VMAPIbooleanlongString[]vmDeviceList(int type) booleanvmDiskCreate(String pool_name, String xml) longbooleanvmGetAllStats(int year, int month, int day, int hour, int sample) intvmGetState(String name) booleanvmInit()String[]vmList()booleanString[]booleanvmPowerOff(String name) booleanvmRegister(String xml) booleanbooleanbooleanvmSecretCreate(String xml, String passwd) booleanvmSnapshotCreate(String name, String xml, int flags) booleanvmSnapshotDelete(String name, String snapshot) booleanvmSnapshotExists(String name) vmSnapshotGetCurrent(String name) String[]vmSnapshotList(String name) booleanvmSnapshotRestore(String name, String snapshot) booleanbooleanintvmStorageGetState(String name) vmStorageGetUUID(String name) String[]booleanvmStorageRegister(String xml) booleanvmStorageStart(String name) booleanvmStorageStop(String name) booleanvmStorageUnregister(String name) booleanlongbooleanvmUnregister(String name)
-
Constructor Details
-
VMJNI
public VMJNI()
-
-
Method Details
-
getInstance
-
vmDeviceList
- Specified by:
vmDeviceListin interfaceVMAPI
-
vmDiskCreate
- Specified by:
vmDiskCreatein interfaceVMAPI
-
vmNetworkListPhys
- Specified by:
vmNetworkListPhysin interfaceVMAPI
-
vmSecretCreate
- Specified by:
vmSecretCreatein interfaceVMAPI
-
vmStorageList
- Specified by:
vmStorageListin interfaceVMAPI
-
vmStorageRegister
- Specified by:
vmStorageRegisterin interfaceVMAPI
-
vmStorageUnregister
- Specified by:
vmStorageUnregisterin interfaceVMAPI
-
vmStorageStart
- Specified by:
vmStorageStartin interfaceVMAPI
-
vmStorageStop
- Specified by:
vmStorageStopin interfaceVMAPI
-
vmStorageGetState
- Specified by:
vmStorageGetStatein interfaceVMAPI
-
vmStorageGetUUID
- Specified by:
vmStorageGetUUIDin interfaceVMAPI
-
vmInit
-
vmStart
-
vmStop
-
vmPowerOff
- Specified by:
vmPowerOffin interfaceVMAPI
-
vmRestart
-
vmSuspend
-
vmResume
-
vmGetState
- Specified by:
vmGetStatein interfaceVMAPI
-
vmList
-
vmGet
-
vmRegister
- Specified by:
vmRegisterin interfaceVMAPI
-
vmUnregister
- Specified by:
vmUnregisterin interfaceVMAPI
-
vmMigrate
-
vmSnapshotCreate
- Specified by:
vmSnapshotCreatein interfaceVMAPI
-
vmSnapshotList
- Specified by:
vmSnapshotListin interfaceVMAPI
-
vmSnapshotExists
- Specified by:
vmSnapshotExistsin interfaceVMAPI
-
vmSnapshotGetCurrent
- Specified by:
vmSnapshotGetCurrentin interfaceVMAPI
-
vmSnapshotRestore
- Specified by:
vmSnapshotRestorein interfaceVMAPI
-
vmSnapshotDelete
- Specified by:
vmSnapshotDeletein interfaceVMAPI
-
vmTotalMemory
public long vmTotalMemory()- Specified by:
vmTotalMemoryin interfaceVMAPI
-
vmFreeMemory
public long vmFreeMemory()- Specified by:
vmFreeMemoryin interfaceVMAPI
-
vmCpuLoad
-
vmGetAllStats
public boolean vmGetAllStats(int year, int month, int day, int hour, int sample) - Specified by:
vmGetAllStatsin interfaceVMAPI
-
vmConnect
-