Class WLSharedMemoryPool
java.lang.Object
javaforce.linux.wayland.WLObject
javaforce.linux.wayland.WLSharedMemoryPool
-
Field Summary
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidcreate_buffer(int new_id, int offset, int width, int height, int stride, int format) voiddestroy()voidresize(int new_size) Methods inherited from class WLObject
dispatchEvent, invokeRequest
-
Constructor Details
-
WLSharedMemoryPool
-
-
Method Details
-
create_buffer
public void create_buffer(int new_id, int offset, int width, int height, int stride, int format) -
destroy
public void destroy() -
resize
public void resize(int new_size)
-