Class TestIPC.TestEndPoint

java.lang.Object
javaforce.tests.TestIPC.TestEndPoint
All Implemented Interfaces:
EndPoint
Enclosing class:
TestIPC

public static class TestIPC.TestEndPoint extends Object implements EndPoint
  • Constructor Details

    • TestEndPoint

      public TestEndPoint(String name)
  • Method Details

    • getEndPointName

      public String getEndPointName()
      Description copied from interface: EndPoint
      Returns end point name in reverse DNS notation. Return null for client end points to have a generic name provided. On Linux the Javaforce package will install a DBus conf that will allow root to use names that start with "javaforce." or you could install your own into /etc/dbus-1/system.d See DBus.getBusName() to get supplied name. Example : com.example.MyService
      Specified by:
      getEndPointName in interface EndPoint
      Returns:
      End Point name (null to request system supplied name)
    • dispatch

      public Object dispatch(String method, Object[] args) throws Exception
      Description copied from interface: EndPoint
      Dispatch function called to this endpoint.
      Specified by:
      dispatch in interface EndPoint
      Parameters:
      method - = method invoked
      args - = arguments
      Returns:
      method return value or null if error
      Throws:
      Exception