Package javaforce.ui


package javaforce.ui
package javaforce.ui; This package includes a UI framework to replace AWT. The GLFW project is used to create Windows and process events. The reason for this package was because Oracle planned to not support many AWT functions in GraalVM (and still doesn't support) so a replacement was developed. Many UI elements have not been completed but development for this framework is basically inactive. Only the basic Window class is maintained for OpenGL apps.