Class updatedesktopdatabase.ActionGroup
java.lang.Object
javaforce.utils.updatedesktopdatabase.ActionGroup
- Enclosing class:
updatedesktopdatabase
- Author:
- pquiring Reads all .desktop files and generates mimeaction.cache This differs from the freedesktop.org version with a new field: Action=open|edit .desktop files can contain this field to distinguish how the app handles the mimetype. It can do both open and edit (comma seperated) but is unlikely. More actions may be created in the future. Format of mimeaction.cache [open] mimetype=desktops... ... [edit] mimetype=desktops... ... jfopen (and jfile) will use this mimeaction.cache to determine how to open files. This allows different apps to handle the same mime-types for different purposes. ie: jview can 'open' jpeg images while jpaint can 'edit' jpeg images. ie: jmedia can 'open' wav files while audacity can 'edit' wav files. If no action field is found "open" is assumed for now. Some pre-defined Actions are built-in. This utility is run by japps automatically. If you install/remove apps manually you will have to run this command manually.
-
Field Summary
FieldsModifier and TypeFieldDescription -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
action
-
mimeList
-
-
Constructor Details
-
ActionGroup
public ActionGroup()
-