Package javaforce.vm
Class Storage
java.lang.Object
javaforce.vm.Storage
- All Implemented Interfaces:
Serializable
- See Also:
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intstatic final intstatic final intstatic final intintstatic final intstatic final intstatic final intstatic final intstatic final int -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanformat(int type) getPath()Returns mount path.intgetState()static String[]list()Returns list of UUID for Storage units registered.static voidbooleanmount()Mount pool.booleanregister()booleanstart()booleanstop()booleanunmount()Unmount pool.boolean
-
Field Details
-
type
public int type -
name
-
uuid
-
host
-
target
-
initiator
-
path
-
TYPE_LOCAL_PART
public static final int TYPE_LOCAL_PART- See Also:
-
TYPE_LOCAL_DISK
public static final int TYPE_LOCAL_DISK- See Also:
-
TYPE_NFS
public static final int TYPE_NFS- See Also:
-
TYPE_ISCSI
public static final int TYPE_ISCSI- See Also:
-
STATE_OFF
public static final int STATE_OFF- See Also:
-
STATE_ON
public static final int STATE_ON- See Also:
-
STATE_BUILD
public static final int STATE_BUILD- See Also:
-
STATE_ERROR
public static final int STATE_ERROR- See Also:
-
TYPE_EXT4
public static final int TYPE_EXT4- See Also:
-
-
Constructor Details
-
Storage
-
-
Method Details
-
list
Returns list of UUID for Storage units registered. -
register
public boolean register() -
unregister
public boolean unregister() -
start
public boolean start() -
stop
public boolean stop() -
getState
public int getState() -
getStateString
-
mount
public boolean mount()Mount pool. This should NOT be required but start() is not working yet. -
unmount
public boolean unmount()Unmount pool. This should NOT be required but stop() is not working yet. -
format
public boolean format(int type) -
getPath
Returns mount path. -
main
-