Class SplitPanel
java.lang.Object
javaforce.webui.Component
javaforce.webui.Container
javaforce.webui.Panel
javaforce.webui.SplitPanel
SplitPanel - divides two Panels vertically or horizontally.
- Author:
- pquiring
-
Nested Class Summary
Nested classes/interfaces inherited from class Component
Component.Event -
Field Summary
Fields inherited from class Component
ArrayType, attrs, AUTO, backclr, borderclr, BOTTOM, CENTER, classes, client, clr, COLUMN, DRAG_EW, DRAG_MOVE, DRAG_NESW, DRAG_NS, DRAG_NWSE, events, height, HIDDEN, HORIZONTAL, id, LEFT, name, NONE, parent, RIGHT, ROW, SCROLL, styles, TOP, VERTICAL, VISIBLE, width, x, y -
Constructor Summary
ConstructorsConstructorDescriptionSplitPanel(int direction) Create SplitPanel with vertical or horizontal divider.SplitPanel(int direction, int flexSide) Create SplitPanel with vertical or horizontal divider. -
Method Summary
Modifier and TypeMethodDescriptionintintvoidinit()Perform any initialization with the client.voidProcess custom events.voidvoidsetDividerPosition(int pos) voidvoidvoidMethods inherited from class Panel
getOverflow, onLoaded, setOverflowMethods inherited from class Container
add, add, count, events, get, get, getAll, getComponent, html, remove, remove, removeAll, set, setClient, setFlexDirectionMethods inherited from class Component
action, addActionListener, addAttr, addChangedListener, addClass, addClickListener, addEvent, addKeyDownListener, addKeyDownListenerPreventDefault, addKeyUpListener, addKeyUpListenerPreventDefault, addLoadedListener, addMouseDownListener, addMouseEnterListener, addMouseMoveListener, addMouseUpListener, addMovedListener, addResizedListener, addValidateListener, addVisibleListener, click, decode, dispatchEvent, enableDragging, encode, getAttrs, getBackColor, getBorderColor, getClient, getColor, getEvents, getHeight, getID, getName, getParent, getProperty, getStyle, getTopParent, gettransform, gettransformorigin, getWidth, getX, getY, hasAttr, hasClass, hasStyle, initInvisible, isLoaded, isPopup, isVisible, onChanged, onClick, onDrawRect, onDrawRect, onKeyDown, onKeyUp, onMouseDown, onMouseEnter, onMouseMove, onMouseUp, onPos, onPosSize, onSize, removeAttr, removeClass, removeStyle, requestPos, requestPosSize, requestSize, sendData, sendEvent, sendOnResize, setAlign, setAutoHeight, setAutoWidth, setBackColor, setBorder, setBorderColor, setBorderGray, setClass, setColor, setDisabled, setFlex, setFocus, setFocusable, setFontSize, setHeight, setMaxHeight, setMaxWidth, setName, setPosition, setProperty, setReadonly, setrotate, setscale, setSize, setStyle, settransform, settransformorigin, settransformorigin, settranslate, setVerticalAlign, setVisible, setWidth, toString, validate
-
Constructor Details
-
SplitPanel
public SplitPanel(int direction) Create SplitPanel with vertical or horizontal divider. The divider will control the size of the left/top component. The other component will flex as needed.- Parameters:
direction- = VERTICAL or HORIZONTAL
-
SplitPanel
public SplitPanel(int direction, int flexSide) Create SplitPanel with vertical or horizontal divider. Based on the flexSide param the divider will control the size of the left/top or bottom/right component. The other component will flex as needed.- Parameters:
direction- = VERTICAL or HORIZONTALflexSide- = the side that will flex (the divider controls the other component's size) VERTICAL = LEFT or RIGHT (Default = RIGHT) HORIZONTAL = TOP or BOTTOM (Default = BOTTOM)
-
-
Method Details
-
init
-
getDirection
public int getDirection() -
setDividerPosition
public void setDividerPosition(int pos) -
getDividerPosition
public int getDividerPosition() -
getLeftComponent
-
getTopComponent
-
getRightComponent
-
getBottomComponent
-
setLeftComponent
-
setTopComponent
-
setRightComponent
-
setBottomComponent
-
onEvent
-