Package javaforce.webui
package javaforce.webui
WebUI is a web-based UI service.
"Codes like a Desktop app, runs in a Browser."
No JavaScript or HTML knowledge required.
Supported browsers:
Chrome, Edge, Firefox, etc.
Not supported:
IE
-
ClassDescriptionAudioBlock (div) container.ButtonCanvas for 2D and 3D output.Centered Panel to display components.CheckBoxWebUI ColorColumn - display components in a column.ComboBoxBase class for all components.Base class for components that can "contain" other components.DimensionFlexBox.Grid LayoutHTML container for generic typesIcon.IFrame to display another webpage.Image.Inline BlockInner Panel to display components with a border.KeyPad for TextComponentLabelLayers Panel.Layout ManagerListBoxMedia : Base class for Audio and Video elements.Menu (place on MenuBar or PopupMenu)MenuBarMenuItemPad - to add paddingPanel to display components.PointPopup MenuPopup Panel (or Window)Progress bar.RectangleResourceRow - display components in a row.Scroll PanelSliderSplitPanel - divides two Panels vertically or horizontally.TableTabbed PanelTextAreaText ComponentTextFieldTitleBar to be placed in PopupPanelToolBarTreeWebUI TreeModelWebUI TreeModelEventWebUI TreeModelListenerTreeNodeWebUI TreePathUpload ButtonVideoWebClient.WebUI HandlerWebUI Server.WebUI Servlet contextWebUIServletContext.XML is a TreeModel data model that encapsules a complete XML file.XMLEvent is an interface for a callback handler used during XML loading.