Class JBus
java.lang.Object
javaforce.bus.JBus
- All Implemented Interfaces:
EndPoint
- Direct Known Subclasses:
JBusClient, JBusServer
-
Field Summary
FieldsModifier and TypeFieldDescriptionDBus options that must be configured before connect(). -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanconnect()Connect to message bus.voidCloses connection to message bus.Dispatches inbound method call.Returns bus name requested or assigned.Returns bus nameInvoke a method on another member on the message bus.voidsetDispatch(Dispatch dispatch) Setup alternative message dispatch.voidsetTimeout(int ms) Set DBus timeout.Invoke a method on all clients that have subscribed to method.booleanSubscribe to a signal from another client.booleanunsubscribe(String sender, String method) Unsubscribe to a signal from another client.
-
Field Details
-
options
DBus options that must be configured before connect().
-
-
Constructor Details
-
JBus
-
-
Method Details
-
setDispatch
Setup alternative message dispatch. -
getEndPointName
Returns bus name- Specified by:
getEndPointNamein interfaceEndPoint- Returns:
- End Point name (null to request system supplied name)
-
dispatch
-
invoke
-
signal
-
subscribe
-
unsubscribe
-
getBusName
Returns bus name requested or assigned. -
setTimeout
public void setTimeout(int ms) Set DBus timeout. -
connect
public boolean connect()Connect to message bus. -
disconnect
public void disconnect()Closes connection to message bus.
-