Interface MediaIO
- All Known Implementing Classes:
MediaInput,MediaOutput,TestCamera,TestMedia
public interface MediaIO
-
Field Summary
Fields -
Method Summary
Modifier and TypeMethodDescriptiondefault intread(MemorySegment data, int size) Default FFM implementation of read().intread(MediaCoder coder, byte[] data) Request to read data.default longseek(long pos, int how) Default FFM implementation of seek().longseek(MediaCoder coder, long pos, int how) Request to seek file.default MemorySegment[]store(MemorySegment[] array) internal to FFM : implementing class must store upcall references until no longer needed.default intwrite(MemorySegment data, int size) Default FFM implementation of write().intwrite(MediaCoder coder, byte[] data) Request to write data.
-
Field Details
-
debug
static final boolean debug- See Also:
-
-
Method Details
-
read
Request to read data.- Parameters:
data- = buffer to receive data
-
read
Default FFM implementation of read(). Do not implement. -
write
Request to write data.- Parameters:
data- = buffer of data to be written.
-
write
Default FFM implementation of write(). Do not implement. -
seek
Request to seek file.- Parameters:
pos- = positionhow- = how to seek (see MediaCoder.SEEK_... types)
-
seek
default long seek(long pos, int how) Default FFM implementation of seek(). Do not implement. -
store
internal to FFM : implementing class must store upcall references until no longer needed. See MediaInput and MediaOutput
-