Class TestIPC.TestEndPoint
java.lang.Object
javaforce.tests.TestIPC.TestEndPoint
- All Implemented Interfaces:
EndPoint
- Enclosing class:
TestIPC
-
Nested Class Summary
Nested Classes -
Constructor Summary
Constructors -
Method Summary
-
Constructor Details
-
TestEndPoint
-
-
Method Details
-
getEndPointName
Description copied from interface:EndPointReturns end point name in reverse DNS notation. Return null for client end points to have a generic name provided. On Linux the Javaforce package will install a DBus conf that will allow root to use names that start with "javaforce." or you could install your own into /etc/dbus-1/system.d See DBus.getBusName() to get supplied name. Example : com.example.MyService- Specified by:
getEndPointNamein interfaceEndPoint- Returns:
- End Point name (null to request system supplied name)
-
dispatch
Description copied from interface:EndPointDispatch function called to this endpoint.
-