Class TestIPC.TestEndPoint.Methods
java.lang.Object
javaforce.tests.TestIPC.TestEndPoint.Methods
- Enclosing class:
TestIPC.TestEndPoint
-
Constructor Summary
Constructors -
Method Summary
-
Constructor Details
-
Methods
public Methods()
-
-
Method Details
-
ping
public boolean ping(int value) ping -
modify
public byte[] modify(byte[] data) Modifies the byte array and returns it. -
process
Process is a long process that will call callback() on the caller. This method MUST return before the timeout occurs on the caller or the caller will generate an exception and will not receive the return value (default = 30 seconds). -
callback
callback to the caller from process()
-