Package javaforce.webui
package javaforce.webui
package javaforce.webui;
WebUI is a web-based UI service.
"Codes like a Desktop app, runs in a Browser."
No JavaScript or HTML knowledge required.
Supported browsers:
Chrome, Edge, Firefox, etc.
Not supported:
IE
-
ClassDescriptionAudioSimple block (div) container.Button Generic button.Centered Panel to display components.WebUI ColorColumn - display components in a column.DimensionFlexBox Fills up space or gap between other components like a spring.Grid LayoutHTML container for generic typesIcon Displays an icon from classpath /javaforce/iconsIFrame to display another webpage.Image.Inline BlockInner Panel to display components with a border.Label Generic Label.Layers Panel.Layout ManagerMenuBarMenuItemPad - to add paddingPointPopup MenuPopup Panel (or Window)Progress bar.RectangleRow - display components in a row.Scroll PanelSliderSplitPanel - divides two Panels vertically or horizontally.Tabbed PanelTextAreaText ComponentTextFieldTitleBar to be placed in PopupPanelToolBarWebUI TreeModelWebUI TreeModelEventWebUI TreeModelListenerVideoXML is a TreeModel data model that encapsules a complete XML file.
Each XML tag (element) is treated as a node in the tree.XMLEvent is an interface for a callback handler used during XML loading.